User messages
-------------

User message has more complicate structure than “system”:

* Time in [H:i:s] format
* Participant name: ``You``, ``Talker`` or ``..``. Name ``...`` is used if several messages from one user were sent
* Message body

For more information please follow to :ref:`mockups <Mockups>` section.
